% Plot Light attenuation, secchi depth, and other clarity "puzzle" metrics
% From lower York River Estuary 2014-2016.
% For Limnology & Oceanography Letters paper
% Includes quick map of York River area
% Code by Jessie Turner November 5, 2021
% Updated May 1, 2022
%
% Requires data: 
%     coastline_cb.mat (coastline for map)
%     dKF_KdZSD.txt (dKF_KdZSD = data from Kelsey Fall et al. 2020)
%     dDP_KdZSD.txt (dDP_KdZSD = CBNERR-VA data from Dave Parrish)
%     dCBP_KdZSD.txt (dCBP_KdZSD = data at CBP station WE4.2 from 2014 to 2016)
%     dKF_Attainment.txt (dKF_Attainment = coincident data from Kelsey Fall et al. 2020)
%     dCBN_Attainment.txt (dCBN_Attainmant = 2014-2016 CBNERR-VA Goodwin Islands data provided by Dave Parrish)
% 
% Requires functions: 
%   sublabel.m
%   makepretty.m
%
% Data source locations and longitude,latitude:
% CBNERR-VA	GoodwinIslands	-76.39222	37.21722
% CBP       WE4.2           -76.38634	37.24181  
%
% K. Fall Stations: (N = 8)
% 1 -76.8774 37.5341
% 2 -76.7696 37.4897
% 3 -76.7307 37.4345
% 4 -76.6845 37.4087
% 5 -76.6564 37.3722
% 6 -76.5704 37.297
% 7 -76.5097 37.2504
% 8 -76.4545 37.2426 

clear all; close all hidden; format shortg;

% Set up figure for four subplots
figure('position',[50   50   1000   800]);
clf
subplotN1 = 2; % number of rows of plots
subplotN2 = 2; % number of columns of subplots

%% Subplot 1: Map
axislims=[-76.9157  -76.2   37.0604   37.7111]; % set axis for map
lon = [-76.8774 
    -76.7696 
    -76.7307 
    -76.6845 
    -76.6564
    -76.5704 
    -76.5097
    -76.4545 
    -76.39222
    -76.38634];
lat = [37.5341
    37.4897
    37.4345
    37.4087
    37.3722
    37.297
    37.2504
    37.2426
    37.21722
    37.24181];
load coastline_cb.mat;
% Begin plotting Subplot 1
plt(1) = subplot(subplotN1,subplotN2,1);
plot(coast_cb(:,1),coast_cb(:,2),'k-','linewidth',1);
axis(axislims);
hold on
plot(lon(1),lat(1),'ko','markerfacecolor','b','markersize',10);
plt1=plot(lon(1:8),lat(1:8),'ko','markerfacecolor','b','markersize',10);
plt2=plot(lon(9),lat(9),'ks','markerfacecolor','r','markersize',10);
plt3=plot(lon(10),lat(10),'k^','markerfacecolor','k','markersize',10);
makepretty;
axis('square');
xlabel('Longitude');ylabel('Latitude');


%% Subplot 2: ZSD and Kd not a line
% Load three sets of data for this plot
filename = 'dKF_KdZSD.txt'; % dataset part 1 (dKF_KdZSD = data from Kelsey Fall et al. 2020)
fileID = fopen(filename);
dKF = cell2mat(textscan(fileID,'%n%n','delimiter',' ','Headerlines',1,'commentstyle','matlab'));
fclose(fileID);
filename = 'dDP_KdZSD.txt'; % dataset part 2 (dDP_KdZSD = CBNERR-VA data given me by Dave Parrish)
fileID = fopen(filename);
dDP = cell2mat(textscan(fileID,'%n%n','delimiter',' ','Headerlines',1,'commentstyle','matlab'));
fclose(fileID);
filename = 'dCBP_KdZSD.txt'; % dataset part 3 (dCBP_KdZSD = from CBP station WE4.2 from 2014 to 2016)
fileID = fopen(filename);
dCBP = cell2mat(textscan(fileID,'%n%n','delimiter',' ','Headerlines',1,'commentstyle','matlab'));
fclose(fileID);
clearvars fileID filename;
KdCBP=dCBP(:,1); ZsdCBP=dCBP(:,2); 
KdKF=dKF(:,1); ZsdKF=dKF(:,2);
KdDP=dDP(:,1); ZsdDP=dDP(:,2);
% Begin plotting Subplot 2
plt(2) = subplot(subplotN1,subplotN2,2);
dat = loglog(KdKF,KdKF.*ZsdKF,'bo',KdDP,KdDP.*ZsdDP,'rs',KdCBP,KdCBP.*ZsdCBP,'k^',[.3,10],[1.45,1.45],'k-');
hold on
grid; axis('square'); axis([.3,10,.45,3.5]);
set(dat,'linewidth',1.5,'markersize',10);
xlabel('Observed K_d (m^{-1})');
ylabel('Observed \alpha');
set(gca,'xticklabels',{'1','10'});
makepretty;

%% Subplot 3: Kd predicted from ZSD would not match observed Kd
Kd_predKF = 1.45./ZsdKF;
Kd_predDP = 1.45./ZsdDP;
Kd_predCBP = 1.45./ZsdCBP;
% Begin plotting subplot 3
plt(3) = subplot(subplotN1,subplotN2,3);
dat = loglog(KdKF,Kd_predKF,'bo',KdDP,Kd_predDP,'rs',KdCBP,Kd_predCBP,'k^',[0.1,10],[0.1,10],'k-');
hold on
grid; axis('square'); axis([0.3,10,0.3,10]);
set(dat,'linewidth',1.5,'markersize',10);
xlabel('Observed K_d (m^{-1})');
ylabel('Predicted K_d (m^{-1}) from: K_d = 1.45 / Z_{SD}');
set(gca,'xticklabels',{'1','10'});
set(gca,'xticklabels',{'1','10'},'yticklabels',{'1','10'});
makepretty;

%% Subplot 4: Kd predicted from dataflow would not match observed Kd
% Load 2 sets of data for this plot
filename = 'dKF_Attainment.txt'; % dataset part 1 (dKF_Attainment = coincident data from Kelsey Fall et al. 2020)
fileID = fopen(filename);
dKF = cell2mat(textscan(fileID,'%n%n%n%n','delimiter',' ','Headerlines',1,'commentstyle','matlab'));
fclose(fileID);
filename = 'dCBN_Attainment.txt'; % dataset part 2 (2014-2016 CBNERR-VA Goodwin Islands data provided by Dave Parrish)
fileID = fopen(filename);
dCBN= cell2mat(textscan(fileID,'%n%n%n%n','delimiter',' ','Headerlines',1,'commentstyle','matlab'));
fclose(fileID);
clearvars fileID filename;
KdKF=dKF(:,1); turbKF=dKF(:,2); ChlaKF=dKF(:,3); SalKF=dKF(:,4);
KdtKF=0.527+0.319*turbKF.^(2/3)+0.0178*SalKF+0.0272*ChlaKF;
KdCBN=dCBN(:,1); turbCBN=dCBN(:,2); ChlaCBN=dCBN(:,3); SalCBN=dCBN(:,4);
KdtKF=0.527+0.319*turbKF.^(2/3)+0.0178*SalKF+0.0272*ChlaKF;
KdtCBN=0.527+0.319*turbCBN.^(2/3)+0.0178*SalCBN+0.0272*ChlaCBN;
% Begin plotting subplot 4
plt(4) = subplot(subplotN1,subplotN2,4);
dat = loglog(KdKF,KdtKF,'bo',KdCBN,KdtCBN,'rs',[.4,10],[.4,10],'k-'); 
grid; axis([0.4,10,.4,10]); axis('square');
hold on; makepretty;
set(dat,'linewidth',1.5,'markersize',10);
xlabel('Observed K_d (m^{-1})');
ylabel({'Predicted K_d (m^{-1}) from: ';...
    'K_d = 0.53 + 0.32 T^{0.67} + 0.018 S + 0.027 Chl'});
set(gca,'xticklabels',{'1','10'},'yticklabels',{'1','10'});
makepretty;


%% Finishing touches on the figure
% Label all subplots with letters
sublabel(plt,20, 54, 'fontsize',20);

% Save Figure
savename = 'Figure_FourPanel_L&O_Paper.png';
print(gcf,savename,'-dpng','-r300');

% Specifically make an extra figure for the legend for all 4 subplots
figure
clf
makepretty;
hold on;
dat=plot(1,1,'bo',2,2,'rs',3,3,'k^'); % 4,4,'k-');
set(dat,'linewidth',1.5,'markersize',10);
ll = legend('Fall (2020)',...
    'Goodwin Islands Station',...
    'Chesapeake Bay Program Station WE4.2'); % 'K_d = 1.45 / Z_{SD}');
makepretty;
set(ll,'location','southoutside');

% Save Legend
savename = 'FigLEGEND_FourPanel_L&O_Paper.png';
print(gcf,savename,'-dpng','-r300');

